@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package MetaCPAN::Client;
 # ABSTRACT: A comprehensive, DWIM-featured client to the MetaCPAN API
-$MetaCPAN::Client::VERSION = '1.013000';
+$MetaCPAN::Client::VERSION = '1.014000';
 use Moo;
 use Carp;
 
@@ -177,7 +177,7 @@ sub _get {
     my $fields_filter = $self->_read_fields( $params );
 
     my $response = $self->fetch(
-        sprintf("%s/%s%s", $type ,$arg, $fields_filter)
+        sprintf("%s/%s%s", $type ,$arg, $fields_filter||'')
     );
     ref $response eq 'HASH'
         or croak sprintf( 'Failed to fetch %s (%s)', ucfirst($type), $arg );
@@ -189,9 +189,10 @@ sub _get {
 sub _read_fields {
     my $self   = shift;
     my $params = shift;
-    $params or return '';
+    $params or return;
 
     my $fields = delete $params->{fields};
+    $fields or return;
 
     if ( ref $fields eq 'ARRAY' ) {
         grep { ref $_ } @$fields
@@ -336,7 +337,7 @@ MetaCPAN::Client - A comprehensive, DWIM-featured client to the MetaCPAN API
 
 =head1 VERSION
 
-version 1.013000
+version 1.014000
 
 =head1 SYNOPSIS
 
@@ -670,7 +671,7 @@ Mickey Nasriachi <mickey@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Sawyer X.
+This software is copyright (c) 2016 by Sawyer X.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
