@@ -2,18 +2,19 @@ use strict;
 use warnings;
 package MetaCPAN::Client::Request;
 # ABSTRACT: Object used for making requests to MetaCPAN
-$MetaCPAN::Client::Request::VERSION = '1.013000';
+$MetaCPAN::Client::Request::VERSION = '1.014000';
 use Moo;
 use Carp;
 use JSON::MaybeXS qw<decode_json encode_json>;
 use Search::Elasticsearch;
-use Search::Elasticsearch::Scroll;
 use Try::Tiny;
 use HTTP::Tiny;
 
 has domain => (
     is      => 'ro',
-    default => sub {'api.metacpan.org'},
+    default => sub {
+        return ( $ENV{METACPAN_DOMAIN} ? $ENV{METACPAN_DOMAIN} : 'api.metacpan.org' );
+    },
 );
 
 has version => (
@@ -91,8 +92,7 @@ sub ssearch {
 
     my $body = $self->_build_body($args, $params);
 
-    my $scroller = Search::Elasticsearch::Scroll->new(
-        es          => $es,
+    my $scroller = $es->scroll_helper(
         search_type => 'scan',
         scroll      => '5m',
         index       => $self->version,
@@ -231,7 +231,7 @@ MetaCPAN::Client::Request - Object used for making requests to MetaCPAN
 
 =head1 VERSION
 
-version 1.013000
+version 1.014000
 
 =head1 ATTRIBUTES
 
@@ -334,7 +334,7 @@ Mickey Nasriachi <mickey@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Sawyer X.
+This software is copyright (c) 2016 by Sawyer X.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
